@@ -18,6 +18,8 @@
 
 from ncps.torch.ltc_cell import LTCCell
 from .cfc_cell import CfCCell
+from .wired_cfc_cell import WiredCfCCell
 from .cfc import CfC
+from .ltc import LTC
 
-__all__ = ['CfC', 'CfCCell','LTCCell']
\ No newline at end of file
+__all__ = ["CfC", "CfCCell", "LTC", "LTCCell", "WiredCfCCell"]
\ No newline at end of file
